==> deepin-home_1.5.5.tar.xz: BUILD/translations/deepin-home/el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>Έρχεται</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="40"/>
        <source>Communication</source>
        <translation>Επικοινωνία</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="41"/>
        <source>Discuss and share here</source>
        <translation>Συζητήστε και μοιραστείτε εδώ</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Bug Report</source>
        <translation>Αναφορά Σφάλματος</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Report issues you found</source>
        <translation>Αναφέρετε θέματα που βρήκατε</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="58"/>
        <source>Suggestions</source>
        <translation>Υποδείξεις</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="59"/>
        <source>Submit your suggestions</source>
        <translation>Υποβάλετε τις υποδείξεις σας</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="73"/>
        <source>Resources</source>
        <translation>Πόροι</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="78"/>
        <source>Questionaire</source>
        <translation>Ερωτηματολόγιο</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="135"/>
        <source>Join US</source>
        <translation>Γίνετε μέλος μας</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="140"/>
        <source>Internal Testing</source>
        <translation>Εσωτερική δοκιμή</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="154"/>
        <source>Community News</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="78"/>
        <source>Messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="81"/>
        <source>Questionaires</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="26"/>
        <source>Launch at system startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="32"/>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="36"/>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="46"/>
        <source>Version: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="47"/>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="52"/>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="76"/>
        <source>Unlogged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="112"/>
        <source>Sign in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="124"/>
        <source>Sign out</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="149"/>
        <source>%1 messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="153"/>
        <source>Mark all as read</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <location filename="../src/maincomponentplugin/offline/Offline.qml" line="20"/>
        <source>Network error, please try later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/offline/Offline.qml" line="26"/>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <location filename="../src/preloadplugin/Preload.qml" line="34"/>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="89"/>
        <source>Expired on: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="117"/>
        <source>Fill In</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-home_1.5.10.tar.xz: BUILD/translations/deepin-home/el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unlogged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Έρχεται</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Newest</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Επικοινωνία</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Συζητήστε και μοιραστείτε εδώ</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Αναφορά Σφάλματος</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Αναφέρετε θέματα που βρήκατε</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Υποδείξεις</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Υποβάλετε τις υποδείξεις σας</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Πόροι</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Ερωτηματολόγιο</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Γίνετε μέλος μας</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Εσωτερική δοκιμή</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>Messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Questionaires</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No more items</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fill In</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Replied</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Resolved</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Evaluating</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Accepted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reproducing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug Report</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Title：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Content：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Email：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device Info：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device Information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Urged</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
